==> haskell-json-ast-0.3.1-6-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-json-ast.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: json-ast
version: 0.3.1
id: json-ast-0.3.1-4fXznkgTEgsKeS8npJzeu5
key: json-ast-0.3.1-4fXznkgTEgsKeS8npJzeu5
license: MIT
copyright: (c) 2016, Nikita Volkov
maintainer: Nikita Volkov <nikita.y.volkov@mail.ru>
author: Nikita Volkov <nikita.y.volkov@mail.ru>
homepage: https://github.com/nikita-volkov/json-ast
synopsis: Universal JSON AST datastructure
abi: c126a48e9a7fec4f948ef0b2cd65dced
exposed: True
exposed-modules:
    JSONAST
import-dirs: /usr/lib/ghc-8.4.3/site-local/json-ast-0.3.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/json-ast-0.3.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/json-ast-0.3.1
hs-libraries: HSjson-ast-0.3.1-4fXznkgTEgsKeS8npJzeu5
depends:
    vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq text-1.2.3.0
    scientific-0.3.6.2-IBbwozwBAuO8Adqyj8FlXl
    unordered-containers-0.2.9.0-KfM11vwfv9j3BnvMvjdQDd base-4.11.1.0
abi-depends: vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq=8ec9732a4c43da9ed60d7a7b8971b540
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             scientific-0.3.6.2-IBbwozwBAuO8Adqyj8FlXl=15b9d897726264a79d0c84c8eea548d3
             unordered-containers-0.2.9.0-KfM11vwfv9j3BnvMvjdQDd=4d1dd6bd73dbf55dc13ef767664a6e82
             base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
haddock-interfaces: /usr/share/doc/haskell-json-ast/html/json-ast.haddock
haddock-html: /usr/share/doc/haskell-json-ast/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-json-ast-0.3.1-7-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-json-ast.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: json-ast
version: 0.3.1
id: json-ast-0.3.1-8mN3bebUS047ijzAD55j7i
key: json-ast-0.3.1-8mN3bebUS047ijzAD55j7i
license: MIT
copyright: (c) 2016, Nikita Volkov
maintainer: Nikita Volkov <nikita.y.volkov@mail.ru>
author: Nikita Volkov <nikita.y.volkov@mail.ru>
homepage: https://github.com/nikita-volkov/json-ast
synopsis: Universal JSON AST datastructure
abi: 67f8172ae695425d155b69c892abe79d
exposed: True
exposed-modules:
    JSONAST
import-dirs: /usr/lib/ghc-8.4.3/site-local/json-ast-0.3.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/json-ast-0.3.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/json-ast-0.3.1
hs-libraries: HSjson-ast-0.3.1-8mN3bebUS047ijzAD55j7i
depends:
    vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq text-1.2.3.0
    scientific-0.3.6.2-IBbwozwBAuO8Adqyj8FlXl
    unordered-containers-0.2.9.0-HkLL4IW6wFT9NZ9Hv37TSa base-4.11.1.0
abi-depends: vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq=8ec9732a4c43da9ed60d7a7b8971b540
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             scientific-0.3.6.2-IBbwozwBAuO8Adqyj8FlXl=15b9d897726264a79d0c84c8eea548d3
             unordered-containers-0.2.9.0-HkLL4IW6wFT9NZ9Hv37TSa=81e1d2b217f05c2ba43642acf6d96f3b
             base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
haddock-interfaces: /usr/share/doc/haskell-json-ast/html/json-ast.haddock
haddock-html: /usr/share/doc/haskell-json-ast/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
